@@ -2,7 +2,7 @@ import socket
 import serial
 class Server:
     """This class create a server"""
-    def __init__(self, port,usbport=""):
+    def __init__(self, port,usbport):
         """This function called when an object is created"""
         self.s = None
         self.host = ""
@@ -10,6 +10,11 @@ class Server:
         self.conn = None
         self.addr = None
         self.usbport = usbport
+        try:
+            self.serial = serial.serial(self.usbport,9600)
+        except:
+            print("connct arduino properly")
+
     def create(self):
         """This create a Server and bind it with host and ip address """
         try:
@@ -28,10 +33,6 @@ class Server:
             data = self.conn.recv(1024)
             if  data:
                 print(data)
-                try:
-                    self.serial = serial.serial(self.usbport,9600)
-                except:
-                    print("connct arduino properly")
                 self.serial.write(data)
             if self.conn.fileno:
                 break;
